@@ -1,24 +1,18 @@
 package Git::Wrapper::File::RawModification;
+{
+  $Git::Wrapper::File::RawModification::VERSION = '0.021';
+}
 # ABSTRACT: Modification of a file in a commit
-$Git::Wrapper::File::RawModification::VERSION = '0.048_090'; # TRIAL
 
-$Git::Wrapper::File::RawModification::VERSION = '0.048090';use 5.006;
+use 5.006;
 use strict;
 use warnings;
 
 sub new {
   my ($class, $filename, $type, $perms_from, $perms_to, $blob_from, $blob_to) = @_;
-
-  my $score;
-  if ( defined $type && $type =~ s{^(.)([0-9]+)$}{$1} ) {
-    $score = $2;
-    (undef, $filename) = split(qr{\s+}, $filename, 2 );
-  }
-
   return bless {
     filename   => $filename,
     type       => $type,
-    score      => $score,
     perms_from => $perms_from,
     perms_to   => $perms_to,
     blob_from  => $blob_from,
@@ -28,7 +22,6 @@ sub new {
 
 sub filename   { shift->{filename} }
 sub type       { shift->{type} }
-sub score      { shift->{score} }
 
 sub perms_from { shift->{perms_from} }
 sub perms_to   { shift->{perms_to} }
@@ -38,19 +31,17 @@ sub blob_to    { shift->{blob_to} }
 
 1;
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Git::Wrapper::File::RawModification - Modification of a file in a commit
 
 =head1 VERSION
 
-version 0.048_090
+version 0.021
 
 =head1 METHODS
 
@@ -62,8 +53,6 @@ Constructor
 
 =head2 type
 
-=head2 score
-
 =head2 perms_from
 
 =head2 perms_to
@@ -105,9 +94,10 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Hans Dieter Pearcey.
+This software is copyright (c) 2008 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
