@@ -1,18 +1,20 @@
 package Git::Wrapper::Log;
+{
+  $Git::Wrapper::Log::VERSION = '0.021';
+}
 # ABSTRACT: Log line of the Git
-$Git::Wrapper::Log::VERSION = '0.048_090'; # TRIAL
 
-$Git::Wrapper::Log::VERSION = '0.048090';use 5.006;
+use 5.006;
 use strict;
 use warnings;
 
 sub new {
   my ($class, $id, %arg) = @_;
-  my $modifications = defined $arg{modifications} ? delete $arg{modifications} : [];
+  my $modifications = defined $arg{modifications} ? $arg{modifications} : [];
   return bless {
     id            => $id,
     attr          => {},
-    modifications => $modifications,
+    modifications => [],
     %arg,
   } => $class;
 }
@@ -37,19 +39,17 @@ sub author { shift->attr->{author} }
 
 1;
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Git::Wrapper::Log - Log line of the Git
 
 =head1 VERSION
 
-version 0.048_090
+version 0.021
 
 =head1 METHODS
 
@@ -100,9 +100,10 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Hans Dieter Pearcey.
+This software is copyright (c) 2008 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
