@@ -3,10 +3,12 @@ use strict;
 use warnings;
 
 package Git::Wrapper::Status;
+{
+  $Git::Wrapper::Status::VERSION = '0.021';
+}
 # ABSTRACT: A specific status information in the Git
-$Git::Wrapper::Status::VERSION = '0.048_090'; # TRIAL
 
-$Git::Wrapper::Status::VERSION = '0.048090';my %modes = (
+my %modes = (
   M   => 'modified',
   A   => 'added',
   D   => 'deleted',
@@ -41,19 +43,17 @@ sub to   { defined( $_[0]->{to} ) ? $_[0]->{to} : '' }
 
 1;
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Git::Wrapper::Status - A specific status information in the Git
 
 =head1 VERSION
 
-version 0.048_090
+version 0.021
 
 =head1 METHODS
 
@@ -100,9 +100,10 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Hans Dieter Pearcey.
+This software is copyright (c) 2008 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
