@@ -1,8 +1,10 @@
 package Git::Wrapper::Statuses;
-# ABSTRACT: Multiple git statuses information
-$Git::Wrapper::Statuses::VERSION = '0.048_090'; # TRIAL
+{
+  $Git::Wrapper::Statuses::VERSION = '0.021';
+}
+# ABSTRACT: 
 
-$Git::Wrapper::Statuses::VERSION = '0.048090';use 5.006;
+use 5.006;
 use strict;
 use warnings;
 
@@ -32,19 +34,17 @@ sub is_dirty {
 
 1;
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Git::Wrapper::Statuses - Multiple git statuses information
+Git::Wrapper::Statuses -  
 
 =head1 VERSION
 
-version 0.048_090
+version 0.021
 
 =head1 METHODS
 
@@ -89,9 +89,10 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Hans Dieter Pearcey.
+This software is copyright (c) 2008 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
